/**
 * EasyBeans
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IDeploymentCore.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.maven.plugin.deployment.api;

import org.apache.maven.plugin.MojoExecutionException;
import org.ow2.util.maven.plugin.deployment.core.Configuration;
import org.ow2.util.maven.plugin.deployment.core.DeployableManager;

/**
 * Interface describing the core of a deployment mojo.
 * @author Vincent Michaud
 */
public interface IDeploymentCore extends ICore {

    /**
     * Launch the core of the mojo.
     * @throws MojoExecutionException Execution error
     */
    void start() throws MojoExecutionException;

    /**
     * Access to the EasyBeans server.
     * @return Instance of EasyBeans server, or null if not initialized
     */
    IPluginServer getServer();

    /**
     * Get the configuration of the goal.
     * @return The configuration, or null if not initialized
     */
    Configuration getConfiguration();

    /**
     * Get the deployable manager.
     * @return The manager, or null if not initialized
     */
    DeployableManager getDeployableManager();

}
