/**
 * EasyBeans
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IDeploymentMojo.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.maven.plugin.deployment.api;

import org.apache.maven.plugin.MojoExecutionException;
import org.ow2.util.maven.plugin.deployment.core.Configuration;
import org.ow2.util.maven.plugin.deployment.mapping.Deployables;


/**
 * Interface describing a deployment mojo.
 * @author Vincent Michaud
 */
public interface IDeploymentMojo extends IMojo {

    /**
     * Create or get a launched server instance.
     * @param core The core of the mojo
     * @return An instance of launched server
     * @throws MojoExecutionException Execution error
     */
    IPluginServer getLaunchedServer(final IDeploymentCore core) throws MojoExecutionException;

    /**
     * Define internal configuration of the mojo.
     * @return The configuration of the mojo
     * @throws MojoExecutionException Execution error
     */
    Configuration defineConfiguration() throws MojoExecutionException;

    /**
     * Define the behavior when a file must be deployed / undeployed.
     * @param core The core of the mojo
     * @return The deployment behavior
     * @throws MojoExecutionException Execution error
     */
    IDeploymentBehavior defineDeploymentBehavior(final IDeploymentCore core) throws MojoExecutionException;

    /**
     * Access to the additional deployables of the project.
     * @return Additional deployables
     */
    Deployables getAdditionalDeployables();

}
