/**
 * EasyBeans
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IMojo.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.maven.plugin.deployment.api;

import java.util.List;
import org.apache.maven.artifact.factory.ArtifactFactory;
import org.apache.maven.artifact.metadata.ArtifactMetadataSource;
import org.apache.maven.artifact.repository.ArtifactRepository;
import org.apache.maven.artifact.resolver.ArtifactResolver;
import org.apache.maven.plugin.logging.Log;
import org.apache.maven.project.MavenProject;
import org.apache.maven.project.MavenProjectBuilder;
import org.codehaus.plexus.context.Context;


/**
 * Interface describing a simple mojo.
 * @author Vincent Michaud
 */
public interface IMojo {

    /**
     * Get the log of plugin.
     * @return The log
     */
    Log getLog();

    /**
     * Get the plexus context of the plugin.
     * @return The context
     */
    Context getPlexusPluginContext();

    /**
     * Access to the Maven project.
     * @return The current Maven project
     */
    MavenProject getProject();

    /**
     * Access to reactor projects.
     * @return Current reactor projects
     */
    List<MavenProject> getReactorProjects();

    /**
     * Get the local repository.
     * @return The local repository
     */
    ArtifactRepository getLocalRepository();

    /**
     * Get the artifact ID of the plugin.
     * @return The artifact ID
     */
    String getPluginArtifactId();

    /**
     * Get the group ID of the plugin.
     * @return The group ID
     */
    String getPluginGroupId();

    /**
     * Get the version of the plugin.
     * @return The version
     */
    String getPluginVersion();

    /**
     * Get the component used to resolve additional artifacts required.
     * @return The artifact resolver
     */
    ArtifactResolver getArtifactResolver();

    /**
     * Get the component used to create artifact instances.
     * @return The artifact factory
     */
    ArtifactFactory getArtifactFactory();

   /**
    * Get the component used to get metadata.
    * @return The metadata source
    */
    ArtifactMetadataSource getMetadataSource();

    /**
     * Get the component used to build Maven project.
     * @return The project builder
     */
    MavenProjectBuilder getProjectBuilder();
}
