/**
 * EasyBeans
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: IPluginServer.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.maven.plugin.deployment.api;


/**
 * Defines operations that are possible with a local or a remote
 * instance of launched server.
 * @author Vincent Michaud
 */
public interface IPluginServer {
    
    /**
     * Deploy an EJB or an EAR.
     * @param filename A deployable
     */
    void deployArchive(final String filename);


    /**
     * Undeploy an EJB or an EAR deployed.
     * @param filename A deployable already deployed on the server
     */
    void undeployArchive(final String filename);



    /**
     * Stop the server.
     */
    void stop();



    /**
     * Determine if the server is stopped or not.
     * @return True if server has been stopped.
     */
    boolean isStopped();


    /**
     * Determine if the server is a remote instance.
     * @return True if server is a remote instance.
     */
    boolean isRemoteInstance();

    /**
     * Get the version of the server.
     * @return A String
     */
    String getVersion();
}
