/**
 * EasyBeans
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: BasicCore.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.maven.plugin.deployment.core;

import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.plugin.logging.Log;
import org.ow2.util.maven.plugin.deployment.api.ICore;
import org.ow2.util.maven.plugin.deployment.api.IMojo;
import org.ow2.util.maven.plugin.deployment.maven.MavenArtifactResolver;
import org.ow2.util.maven.plugin.deployment.maven.MavenLog;
import org.ow2.util.maven.plugin.deployment.maven.MavenPluginClassloader;


/**
 * Abstract base class managing additional deployed archives specified in the POM.
 * @author Vincent Michaud
 */
public class BasicCore implements ICore {

    /**
     * A deployment mojo.
     */
    private IMojo mojo = null;

    /**
     * The log.
     */
    private Log log = null;

    /**
     * The artifact resolver.
     */
    private MavenArtifactResolver artifactResolver;

    /**
     * The classloader of the plugin.
     */
    private MavenPluginClassloader pluginClassloader;


    /****************************************************/
    /*                 Members functions                */
    /****************************************************/

    /**
     * Contructor.
     * @param mojo A mojo
     */
    public BasicCore(final IMojo mojo) throws MojoExecutionException {
        this.mojo = mojo;
        this.log = mojo.getLog();
        MavenLog.setLog(this.log);
        this.pluginClassloader = MavenPluginClassloader.getInstance(mojo.getPlexusPluginContext());
        this.artifactResolver = new MavenArtifactResolver(mojo.getProject(), mojo.getLocalRepository(),
                                                          mojo.getArtifactResolver(), mojo.getMetadataSource(),
                                                          mojo.getArtifactFactory(), mojo.getProjectBuilder(),
                                                          mojo.getPluginGroupId(), mojo.getPluginArtifactId(),
                                                          mojo.getPluginVersion());
    }

    /**
     * Get the mojo.
     * @param classType The class of the mojo
     * @param <T> Type of the mojo.
     * @return The mojo
     */
    protected <T extends IMojo> T getMojo(final Class<T> classType) {
        return classType.cast(this.mojo);
    }


    /****************************************************/
    /*                ICore implementation              */
    /****************************************************/

    
    /**
     * Get the log of plugin.
     * @return The log
     */
    public Log getLog() {
        return this.log;
    }

    /**
     * Get the artifact resolver.
     * @return The artifact resolver
     */
    public MavenArtifactResolver getArtifactResolver() {
        return this.artifactResolver;
    }

    /**
     * Get the classloader of the plugin.
     * @return The classloader of the plugin
     */
    public MavenPluginClassloader getPluginClassloader() {
        return this.pluginClassloader;
    }

}
