/**
 * EasyBeans
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: BoundDeploymentCore.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.maven.plugin.deployment.core;

import java.io.File;
import org.apache.maven.plugin.MojoExecutionException;
import org.apache.maven.project.MavenProject;
import org.ow2.util.maven.plugin.deployment.core.DeployableManager.ProcessAction;
import org.ow2.util.maven.plugin.deployment.api.IDeploymentBoundMojo;



/**
 * Class representing goal which must be bound to the Maven project lifecycle.
 * This mojo provide a simple deployment of the current project resource.
 * @author Vincent Michaud
 */
public class BoundDeploymentCore extends AbstractDeploymentCore implements ProcessAction {

    /**
     * Contructor.
     * @param depMojo A deployment mojo
     */
    public BoundDeploymentCore(final IDeploymentBoundMojo depMojo) throws MojoExecutionException {
        super(depMojo);
    }

    /****************************************************/
    /*                 Members functions                */
    /****************************************************/

    /**
     * Check the project and deploy found archives. This function must be
     * executed when the goal run is bound to the build lifecycle.
     * @throws MojoExecutionException If plugin configuration is not correct
     */
    protected void manageDeployment() throws MojoExecutionException {

        // Get the instance of the deployment mojo.
        IDeploymentBoundMojo depMojo = getMojo(IDeploymentBoundMojo.class);

        // Get the deployable manager.
        DeployableManager manager = getDeployableManager();

        // Add the current project to the deployables.
        MavenProject project = depMojo.getProject();
        if (getConfiguration().isAllowedPackaging(project.getPackaging())) {
            manager.addResource(project);
        }

        // Process deployment action on the deployable.
        manager.processAction(this);
    }

    /**
     * Allow to deploy only existing files.
     * @param mainPath Main canonical path of the deployable
     * @param mainFile Main file of the deployable
     * @param secondaryPath Secondary canonical path of the deployable
     * @param secondaryFile Secondary file of the deployable
     */
    public void process(final String mainPath, final File mainFile,
                        final String secondaryPath, final File secondaryFile) {
        if (mainFile.exists()) {
            executeDeploymentAction(mainPath, mainFile);
        } else if (secondaryFile != null && secondaryFile.exists()) {
            executeDeploymentAction(secondaryPath, secondaryFile);
        }
    }
}


