/**
 * EasyBeans
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Deployables.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.maven.plugin.deployment.mapping;

import java.util.Collections;
import java.util.List;



/**
 * Deployable representation. This class is mapped by Maven with the POM
 * configuration file.
 * @author Alexandre Deneux
 * @author Bilel Souadnia
 */
public class Deployables {

    /**
     * List of deployable URLs.
     */
    private List<String> urls = Collections.emptyList();

    /**
     * List of deployable Files.
     */
    private List<String> files = Collections.emptyList();

    /**
     * List of directories to scan.
     */
    private List<String> directories = Collections.emptyList();

    /**
     * List of deployable Artifacts.
     */
    private List<Artifact> artifacts = Collections.emptyList();

    /**
     * Get the list of deployable Artifacts.
     * @return List of Artifact Item
     */
    public List<Artifact> getArtifacts() {
        return this.artifacts;
    }

    /**
     * Set the list of deployable Artifacts.
     * @param artifacts List of Artifacts
     */
    public void setArtifacts(final List<Artifact> artifacts) {
        this.artifacts = artifacts;
    }

    /**
     * Get the list of deployable files.
     * @return List of files
     */
    public List<String> getFiles() {
        return this.files;
    }

    /**
     * Set the list of deployable files.
     * @param files List of files
     */
    public void setFiles(final List<String> files) {
        this.files = files;
    }

    /**
     * Get the list of deployable URLs.
     * @return List of URLs
     */
    public List<String> getUrls() {
        return this.urls;
    }

    /**
     * Set the list of deployable URLs.
     * @param urls List of URLs
     */
    public void setUrls(final List<String> urls) {
        this.urls = urls;
    }



    /**
     * Get the list of directories to deploy.
     * @return List of directories
     */
    public List<String> getDirectories() {
        return this.directories;
    }

    /**
     * Set the list of directories to deploy.
     * @param directories List of directories
     */
    public void setDirectories(final List<String> directories) {
        this.directories = directories;
    }

}
