/**
 * EasyBeans
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: easybeans@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Couple.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.util.maven.plugin.deployment.utils;


/**
 * Simple class storing two elements.
 * @author Vincent Michaud
 * @param <E1> Type of the first element
 * @param <E2> Type of the second element
 */
public class Couple<E1, E2> {

    /**
     * First element.
     */
    private E1 e1;

    /**
     * Second element.
     */
    private E2 e2;


    /**
     * Constructor.
     */
    public Couple() {
        this.e1 = null;
        this.e2 = null;
    }
    
    
    /**
     * Constructor.
     * @param e1 First element
     * @param e2 Second element
     */
    public Couple(final E1 e1, final E2 e2) {
        this.e1 = e1;
        this.e2 = e2;
    }


    /**
     * Set the first element.
     * @param e1 The element
     */
    public void setFirst(final E1 e1) {
        this.e1 = e1;
    }

    /**
     * Get the first element.
     * @return The element
     */
    public E1 first() {
        return e1;
    }

    /**
     * Set the second element.
     * @param e2 The element
     */
    public void setSecond(final E2 e2) {
        this.e2 = e2;
    }

    /**
     * Get the second element.
     * @return The element
     */
    public E2 second() {
        return e2;
    }


    /**
     * Return a string representing the couple.
     * @return A string
     */
    @Override
    public String toString() {
        StringBuffer buffer = new StringBuffer("( ");
        if (this.e1 == null) {
            buffer.append("null");
        } else {
            buffer.append(this.e1.toString());
        }
        buffer.append(" ; ");
        if (this.e2 == null) {
            buffer.append("null");
        } else {
            buffer.append(this.e2.toString());
        }
        buffer.append(" )");
        return buffer.toString();
    }
}
